use std::ops::Deref;

use bevy::math::UVec2;
use bevy::prelude::*;

pub const WORLD_TILE_SIZE: f32 = 16.0;

/// Track the location of an entity within a grid
#[derive(Default, Debug, Copy, Clone, Eq, PartialEq, Component)]
#[repr(transparent)]
pub struct GridPosition(pub UVec2);
impl Deref for GridPosition {
	type Target = UVec2;
	fn deref(&self) -> &Self::Target {
		&self.0
	}
}

/// Take an entity's position on a grid, and sync it up to the transform used to render
/// the sprite
pub fn sync_grid_to_transform(mut query: Query<(&GridPosition, &mut Transform)>) {
	for (position, mut transform) in &mut query {
		transform.translation = ((position.as_vec2() * WORLD_TILE_SIZE) + (WORLD_TILE_SIZE / 2.0))
			.extend(transform.translation.z);
	}
}
